==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/ia.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Compartir Federate",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Esque tu vole adder le Compartir Remote {name} de {owner}@{remote}?",
    "Remote share" : "Compartir Remote",
    "Remote share password" : "Contrasigno del Compartir Remote",
    "Cancel" : "Cancellar",
    "Add remote share" : "Adder le Compartir Remote",
    "Copy" : "Copiar",
    "Copied!" : "Copiate!",
    "Not supported!" : "Non supportate!",
    "Press ⌘-C to copy." : "Pulsa ⌘-C pro copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C pro copiar.",
    "Invalid Federated Cloud ID" : "ID del Nube Federate",
    "Server to server sharing is not enabled on this server" : "Le Compartir de Servitor a Servitor non es activate in iste servitor",
    "Couldn't establish a federated share." : "Impossibile establir le Compartir Federate.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Impossibile establir le Compartir Federate, possibilemente le contrasigno esseva incorrecte.",
    "Federated Share request was successful, you will receive a invitation. Check your notifications." : "Le demanda pro un Compartir Federate ha successo, tu recipera un invitation. Verifica tu notificationes.",
    "The mountpoint name contains invalid characters." : "Le nomine pro le puncto de montage contine characteres non valide.",
    "Not allowed to create a federated share with the owner." : "Il non es permittite crear le Compartir Federate con le proprietario.",
    "Invalid or untrusted SSL certificate" : "Certificato SSL non valide o non fiduciari",
    "Could not authenticate to remote share, password might be wrong" : "Impossibile authenticar al Compartir Remote, le contrasigno debe esser incorrecte",
    "Storage not valid" : "Immagazinage non valide",
    "Federated Share successfully added" : "Le Compartir Federate addite con successo",
    "Couldn't add remote share" : "Impossibile adder le Compartir Remote",
    "Sharing %s failed, because this item is already shared with %s" : "Compartir %s falleva, proque iste elemento ja es compartite con %s",
    "Not allowed to create a federated share with the same user" : "Il non es permittite crear le Compartir Federate con le mesme usator.",
    "File is already shared with %s" : "File ja es compartite con %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Compartir %s falleva, il es impossibile trovar %s: possibilemente le servitor es actualmente non accessibile o usa un certificato auto-signate.",
    "Could not find share" : "Impossibile trovar le compartite",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Tu recipeva \"%3$s\" como un compartimento remote de %1$s (in nomine de %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Tu recipeva {share} como un compartimento remote de {user} (in nomine de {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Tu recipeva \"%3$s\" como un compartimento remote de %1$s",
    "You received {share} as a remote share from {user}" : "Tu recipeva {share} como un compartimento remote de {user}",
    "Accept" : "Acceptar",
    "Decline" : "Refusar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Comparti con me per mi ID de Nube Federate #Nextcloud, vide %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Comparti con me per mi ID de Nube Federate #Nextcloud",
    "Federated Cloud Sharing" : "Compartimento del Nube Federate",
    "Open documentation" : "Documentation aperte",
    "Allow users on this server to send shares to other servers" : "Permitter usatores in iste servitor a inviar elementos compartite a altere servitores",
    "Allow users on this server to receive shares from other servers" : "Permitter usatores in iste servitor a reciper elementos compartite ex altere servitores",
    "Federated Cloud" : "Nube Federate",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federate:",
    "Share it:" : "Comparti lo:",
    "Add to your website" : "Adde a tu sito web",
    "Share with me via Nextcloud" : "Comparti con me via Nextcloud",
    "HTML Code:" : "Codice HTML:",
    "Search global and public address book for users" : "Cercar pro usatores in adressarios global e public"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/ia.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Compartir Federate",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Esque tu vole adder le Compartir Remote {name} de {owner}@{remote}?",
    "Remote share" : "Compartir Remote",
    "Remote share password" : "Contrasigno del Compartir Remote",
    "Cancel" : "Cancellar",
    "Add remote share" : "Adder le Compartir Remote",
    "Copy" : "Copiar",
    "Copied!" : "Copiate!",
    "Not supported!" : "Non supportate!",
    "Press ⌘-C to copy." : "Pulsa ⌘-C pro copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C pro copiar.",
    "Invalid Federated Cloud ID" : "ID del Nube Federate",
    "Server to server sharing is not enabled on this server" : "Le Compartir de Servitor a Servitor non es activate in iste servitor",
    "Couldn't establish a federated share." : "Impossibile establir le Compartir Federate.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Impossibile establir le Compartir Federate, possibilemente le contrasigno esseva incorrecte.",
    "Federated Share request was successful, you will receive a invitation. Check your notifications." : "Le demanda pro un Compartir Federate ha successo, tu recipera un invitation. Verifica tu notificationes.",
    "The mountpoint name contains invalid characters." : "Le nomine pro le puncto de montage contine characteres non valide.",
    "Not allowed to create a federated share with the owner." : "Il non es permittite crear le Compartir Federate con le proprietario.",
    "Invalid or untrusted SSL certificate" : "Certificato SSL non valide o non fiduciari",
    "Could not authenticate to remote share, password might be wrong" : "Impossibile authenticar al Compartir Remote, le contrasigno debe esser incorrecte",
    "Storage not valid" : "Immagazinage non valide",
    "Federated Share successfully added" : "Le Compartir Federate addite con successo",
    "Couldn't add remote share" : "Impossibile adder le Compartir Remote",
    "Sharing %s failed, because this item is already shared with %s" : "Compartir %s falleva, proque iste elemento ja es compartite con %s",
    "Not allowed to create a federated share with the same user" : "Il non es permittite crear le Compartir Federate con le mesme usator.",
    "File is already shared with %s" : "File ja es compartite con %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Compartir %s falleva, il es impossibile trovar %s: possibilemente le servitor es actualmente non accessibile o usa un certificato auto-signate.",
    "Could not find share" : "Impossibile trovar le compartite",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Tu recipeva \"%3$s\" como un compartimento remote de %1$s (in nomine de %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Tu recipeva {share} como un compartimento remote de {user} (in nomine de {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Tu recipeva \"%3$s\" como un compartimento remote de %1$s",
    "You received {share} as a remote share from {user}" : "Tu recipeva {share} como un compartimento remote de {user}",
    "Accept" : "Acceptar",
    "Decline" : "Refusar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Comparti con me per mi ID de Nube Federate #Nextcloud, vide %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Comparti con me per mi ID de Nube Federate #Nextcloud",
    "Federated Cloud Sharing" : "Compartimento del Nube Federate",
    "Open documentation" : "Documentation aperte",
    "Allow users on this server to send shares to other servers" : "Permitter usatores in iste servitor a inviar elementos compartite a altere servitores",
    "Allow users on this server to receive shares from other servers" : "Permitter usatores in iste servitor a reciper elementos compartite ex altere servitores",
    "Federated Cloud" : "Nube Federate",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federate:",
    "Add to your website" : "Adde a tu sito web",
    "Share with me via Nextcloud" : "Comparti con me via Nextcloud",
    "HTML Code:" : "Codice HTML:",
    "Search global and public address book for users" : "Cercar pro usatores in adressarios global e public",
    "Share it:" : "Comparti lo:"
},
"nplurals=2; plural=(n != 1);");
